@@ -840,5 +840,5 @@ func getDomainWithMockResolver(t *testing.T, domainName string, namespaceID int)
 			SubPath:    "",
 		}, nil)
 
-	return domain.New(domainName, "", "", "", mockResolver)
+	return domain.New(domainName, "", "", "", namespaceID, mockResolver)
 }
