@@ -812,9 +812,8 @@ func TestDiskDisabledFailsToServeFileAndZipContent(t *testing.T) {
 
 		// give the process enough time to write the log message
 		require.Eventually(t, func() bool {
-			require.Contains(t, logBuf.String(), "cannot serve from disk", "log mismatch")
-			return true
-		}, time.Second, 10*time.Millisecond)
+			return strings.Contains(logBuf.String(), "cannot serve from disk")
+		}, time.Second, 10*time.Millisecond, "log mismatch")
 	}
 }
 
@@ -840,7 +839,6 @@ func TestSlowRequests(t *testing.T) {
 	require.Error(t, err, "cancelling the context should trigger this error")
 
 	require.Eventually(t, func() bool {
-		require.Contains(t, logBuf.String(), "\"status\":404", "status mismatch")
-		return true
-	}, time.Second, time.Millisecond)
+		return strings.Contains(logBuf.String(), "\"status\":404")
+	}, time.Second, 10*time.Millisecond, "status mismatch: expected status 404 in logs")
 }
